![ramjet_engine](docs/ramjet_engine.png)

# RAMjET: RApid MachinE-learned Triage

RAMjET is a framework for producing neural networks to characterize phenomena in astrophysical photometric data.

RAMjET is currently in alpha. This repository is currently oriented toward the RAMjET development team and is not yet intended for a general audience.

[See here for documentation.](https://astroramjet.readthedocs.io/en/latest/)
